[or-cvs] Finish renaming rend_service field

Nick Mathewson nickm at seul.org
Fri Apr 2 23:44:48 UTC 2004


Update of /home/or/cvsroot/src/or
In directory moria.mit.edu:/tmp/cvs-serv2644/src/or

Modified Files:
	circuit.c or.h rendmid.c rendservice.c 
Log Message:
Finish renaming rend_service field

Index: or.h
===================================================================
RCS file: /home/or/cvsroot/src/or/or.h,v
retrieving revision 1.284
retrieving revision 1.285
diff -u -d -r1.284 -r1.285
--- or.h	2 Apr 2004 23:38:26 -0000	1.284
+++ or.h	2 Apr 2004 23:44:45 -0000	1.285
@@ -698,7 +698,7 @@
 circuit_t *circuit_get_by_conn(connection_t *conn);
 circuit_t *circuit_get_newest(connection_t *conn,
                               int must_be_open, uint8_t conn_purpose);
-circuit_t *circuit_get_next_by_service_and_purpose(circuit_t *circuit,
+circuit_t *circuit_get_next_by_pk_and_purpose(circuit_t *circuit,
                                              const char *servid, int purpose);
 circuit_t *circuit_get_rendezvous(const char *cookie);
 

Index: rendmid.c
===================================================================
RCS file: /home/or/cvsroot/src/or/rendmid.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- rendmid.c	2 Apr 2004 23:30:53 -0000	1.3
+++ rendmid.c	2 Apr 2004 23:44:46 -0000	1.4
@@ -67,7 +67,7 @@
 
   /* Close any other intro circuits with the same pk. */
   c = NULL;
-  while ((c = circuit_get_next_by_service_and_purpose(
+  while ((c = circuit_get_next_by_pk_and_purpose(
                                 c,pk_digest,CIRCUIT_PURPOSE_INTRO_POINT))) {
     log_fn(LOG_INFO, "Replacing old circuit %d for service %s", c->p_circ_id, hexid);
     circuit_mark_for_close(c);
@@ -75,7 +75,7 @@
 
   /* Now, set up this circuit. */
   circ->purpose = CIRCUIT_PURPOSE_INTRO_POINT;
-  memcpy(circ->rend_service, pk_digest, 20);
+  memcpy(circ->rend_pk_digest, pk_digest, 20);
 
   log_fn(LOG_INFO, "Established introduction point on circuit %d for service %s",
          circ->p_circ_id, hexid);
@@ -104,7 +104,7 @@
   }
 
   /* The first 20 bytes are all we look at: they have a hash of Bob's PK. */
-  intro_circ = circuit_get_next_by_service_and_purpose(
+  intro_circ = circuit_get_next_by_pk_and_purpose(
                              NULL, request, CIRCUIT_PURPOSE_INTRO_POINT);
   if (!intro_circ) {
     log_fn(LOG_WARN,

Index: rendservice.c
===================================================================
RCS file: /home/or/cvsroot/src/or/rendservice.c,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -d -r1.13 -r1.14
--- rendservice.c	2 Apr 2004 23:30:54 -0000	1.13
+++ rendservice.c	2 Apr 2004 23:44:46 -0000	1.14
@@ -340,7 +340,7 @@
     log_fn(LOG_WARN, "Got an INTRODUCE2 cell for an unrecognized service");
     return -1;
   }
-  if (!memcmp(circuit->rend_service, request, 20)) {
+  if (!memcmp(circuit->rend_pk_digest, request, 20)) {
     log_fn(LOG_WARN, "Got an INTRODUCE2 cell for the wrong service");
     return -1;
   }
@@ -398,7 +398,8 @@
   }
   assert(launched->build_state);
   /* Fill in the circuit's state. */
-  memcpy(launched->rend_service, circuit->rend_service,CRYPTO_SHA1_DIGEST_LEN);
+  memcpy(launched->rend_pk_digest, circuit->rend_pk_digest,
+         CRYPTO_SHA1_DIGEST_LEN);
   memcpy(launched->rend_cookie, r_cookie, REND_COOKIE_LEN);
   launched->build_state->pending_final_cpath = cpath =
     tor_malloc_zero(sizeof(crypt_path_t));
@@ -431,7 +432,7 @@
            nickname);
     return -1;
   }
-  memcpy(launched->rend_service, service->pk_digest, CRYPTO_SHA1_DIGEST_LEN);
+  memcpy(launched->rend_pk_digest, service->pk_digest, CRYPTO_SHA1_DIGEST_LEN);
 
   return 0;
 }
@@ -449,7 +450,7 @@
 
   assert(circuit->purpose == CIRCUIT_PURPOSE_S_ESTABLISH_INTRO);
   assert(circuit->cpath);
-  service = rend_service_get_by_pk_digest(circuit->rend_service);
+  service = rend_service_get_by_pk_digest(circuit->rend_pk_digest);
   if (!service) {
     log_fn(LOG_WARN, "Internal error: unrecognized service ID on introduction circuit");
     goto err;
@@ -499,7 +500,7 @@
   hop = circuit->build_state->pending_final_cpath;
   assert(hop);
 
-  service = rend_service_get_by_pk_digest(circuit->rend_service);
+  service = rend_service_get_by_pk_digest(circuit->rend_pk_digest);
   if (!service) {
     log_fn(LOG_WARN, "Internal error: unrecognized service ID on introduction circuit");
     goto err;
@@ -567,7 +568,7 @@
         goto remove_point;
       circ = NULL;
       found = 1;
-      while ((circ = circuit_get_next_by_service_and_purpose(
+      while ((circ = circuit_get_next_by_pk_and_purpose(
                                                 circ,service->pk_digest,
                                                 CIRCUIT_PURPOSE_S_ESTABLISH_INTRO))) {
         assert(circ->cpath);



More information about the tor-commits mailing list
Index: circuit.c
===================================================================
RCS file: /home/or/cvsroot/src/or/circuit.c,v
retrieving revision 1.172
retrieving revision 1.173
diff -u -d -r1.172 -r1.173
--- circuit.c	2 Apr 2004 23:38:26 -0000	1.172
+++ circuit.c	2 Apr 2004 23:44:45 -0000	1.173
@@ -329,12 +329,12 @@
 }
 
 /* Return the first circuit in global_circuitlist after 'start' whose
  * rend_service field is servid and whose purpose is purpose. Returns
  * NULL if no circuit is found.  If 'start' is null, begin at the start of
  * the list.
  */
-circuit_t *circuit_get_next_by_service_and_purpose(circuit_t *start,
-                                        const char *servid, int purpose)
+circuit_t *circuit_get_next_by_pk_and_purpose(circuit_t *start,
+                                         const char *digest, int purpose)
 {
   circuit_t *circ;
   if (start == NULL)
@@ -347,7 +347,7 @@
       continue;
     if (circ->purpose != purpose)
       continue;
-    if (!memcmp(circ->rend_service, servid, CRYPTO_SHA1_DIGEST_LEN))
+    if (!memcmp(circ->rend_pk_digest, digest, CRYPTO_SHA1_DIGEST_LEN))
       return circ;
   }
   return NULL;
@@ -329,12 +329,12 @@
 
 /* Return the first circuit in global_circuitlist after 'start' whose
- * rend_service field is servid and whose purpose is purpose. Returns
+ * rend_pk_digest field is 'digest' and whose purpose is purpose. Returns
  * NULL if no circuit is found.  If 'start' is null, begin at the start of
  * the list.
